@@ -1,4 +1,4 @@
-import unittest
+import unittest2 as unittest
 
 from celery import registry
 from celery.task import Task, PeriodicTask
@@ -24,42 +24,42 @@ class TestTaskRegistry(unittest.TestCase):
     def assertRegisterUnregisterCls(self, r, task):
         self.assertRaises(r.NotRegistered, r.unregister, task)
         r.register(task)
-        self.assertTrue(task.name in r)
+        self.assertIn(task.name, r)
 
     def assertRegisterUnregisterFunc(self, r, task, task_name):
         self.assertRaises(r.NotRegistered, r.unregister, task_name)
         r.register(task, task_name)
-        self.assertTrue(task_name in r)
+        self.assertIn(task_name, r)
 
     def test_task_registry(self):
         r = registry.TaskRegistry()
-        self.assertTrue(isinstance(r.data, dict),
+        self.assertIsInstance(r.data, dict,
                 "TaskRegistry has composited dict")
 
         self.assertRegisterUnregisterCls(r, TestTask)
         self.assertRegisterUnregisterCls(r, TestPeriodicTask)
 
         tasks = dict(r)
-        self.assertTrue(isinstance(tasks.get(TestTask.name), TestTask))
-        self.assertTrue(isinstance(tasks.get(TestPeriodicTask.name),
-                                   TestPeriodicTask))
+        self.assertIsInstance(tasks.get(TestTask.name), TestTask)
+        self.assertIsInstance(tasks.get(TestPeriodicTask.name),
+                                   TestPeriodicTask)
 
         regular = r.regular()
-        self.assertTrue(TestTask.name in regular)
-        self.assertFalse(TestPeriodicTask.name in regular)
+        self.assertIn(TestTask.name, regular)
+        self.assertNotIn(TestPeriodicTask.name, regular)
 
         periodic = r.periodic()
-        self.assertFalse(TestTask.name in periodic)
-        self.assertTrue(TestPeriodicTask.name in periodic)
+        self.assertNotIn(TestTask.name, periodic)
+        self.assertIn(TestPeriodicTask.name, periodic)
 
-        self.assertTrue(isinstance(r[TestTask.name], TestTask))
-        self.assertTrue(isinstance(r[TestPeriodicTask.name],
-                                   TestPeriodicTask))
+        self.assertIsInstance(r[TestTask.name], TestTask)
+        self.assertIsInstance(r[TestPeriodicTask.name],
+                                   TestPeriodicTask)
 
         r.unregister(TestTask)
-        self.assertFalse(TestTask.name in r)
+        self.assertNotIn(TestTask.name, r)
         r.unregister(TestPeriodicTask)
-        self.assertFalse(TestPeriodicTask.name in r)
+        self.assertNotIn(TestPeriodicTask.name, r)
 
         self.assertTrue(TestTask().run())
         self.assertTrue(TestPeriodicTask().run())
