@@ -11,6 +11,7 @@ from celery.execute.trace import TaskTrace
 from celery.loaders import current_loader
 from celery.registry import tasks
 from celery.utils import noop, kwdict, fun_takes_kwargs
+from celery.utils.compat import any
 from celery.utils.mail import mail_admins
 from celery.worker import state
 
@@ -414,7 +415,10 @@ class TaskRequest(object):
 
         task_obj = tasks.get(self.task_name, object)
         send_error_email = conf.CELERY_SEND_TASK_ERROR_EMAILS and not \
-                                task_obj.disable_error_emails
+                                task_obj.disable_error_emails and not any(
+                                    isinstance(exc_info.exception, whexc)
+                                    for whexc in
+                                    conf.CELERY_TASK_ERROR_WHITELIST)
         if send_error_email:
             subject = self.email_subject.strip() % context
             body = self.email_body.strip() % context
